@@ -4,7 +4,7 @@ from django_pagarme import views
 
 app_name = 'django_pagarme'
 urlpatterns = [
-    path('capture/<str:token>', views.capture, name='capture'),
+    path('capture/<slug:slug>/<str:token>', views.capture, name='capture'),
     path('obrigado/<slug:slug>', views.thanks, name='thanks'),
     path('notification/<slug:slug>', views.notification, name='notification'),
     path('pagarme/<slug:slug>', views.pagarme, name='pagarme'),
